@@ -80,7 +80,7 @@
 #' import.}
 #'
 #'
-#' @section Function version: 0.15.2
+#' @section Function version: 0.15.5
 #'
 #'
 #' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
@@ -265,19 +265,53 @@ read_BIN2R <- function(
   }
 
 
+  # Config --------------------------------------------------------------------------------------
+  ##set file_link for internet downloads
+  file_link <- NULL
+  on_exit <- function(){
+    if(!is.null(file_link)){
+      unlink(file_link)
+    }
+
+  }
+  on.exit(expr = on_exit())
+
 
   # Integrity checks ------------------------------------------------------
 
   ##check if file exists
   if(!file.exists(file)){
 
-    stop("[read_BIN2R()] File does not exists!")
+    ##check whether the file as an URL
+    if(grepl(pattern = "http", x = file, fixed = TRUE)){
+      if(verbose){
+        cat("[read_BIN2R()] URL detected, checking connection ... ")
+      }
+
+      ##check URL
+      if(!httr::http_error(file)){
+        if(verbose) cat("OK")
+
+        ##dowload file
+        file_link <- tempfile("read_BIN2R_FILE")
+        download.file(file, destfile = file_link, quiet = ifelse(verbose, FALSE, TRUE), mode = "wb")
+
+      }else{
+        cat("FAILED")
+        stop("[read_BIN2R()] File does not exist!", call. = FALSE)
+
+      }
+
+    }else{
+      stop("[read_BIN2R()] File does not exist!", call. = FALSE)
+
+    }
 
   }
 
   ##check if file is a BIN or BINX file
-  if(!(TRUE%in%(c("BIN", "BINX", "bin", "binx")%in%tail(
-    unlist(strsplit(file, split = "\\.")), n = 1)))){
+  if(!(TRUE%in%(c("BIN", "BINX", "bin", "binx")%in%sub(pattern = "%20", replacement = "", x = tail(
+    unlist(strsplit(file, split = "\\.")), n = 1), fixed = TRUE)))){
 
     try(
       stop(
@@ -287,6 +321,12 @@ read_BIN2R <- function(
 
   }
 
+  ##set correct file name of file_link was set
+  if(!is.null(file_link)){
+    file <- file_link
+
+  }
+
   # Config ------------------------------------------------------------------
 
   ##set supported BIN format version
@@ -308,7 +348,7 @@ read_BIN2R <- function(
 
 
   ##start for BIN-file check up
-  while(length(temp.VERSION<-readBin(con, what="raw", 1, size=1, endian="litte"))>0) {
+  while(length(temp.VERSION<-readBin(con, what="raw", 1, size=1, endian="little"))>0) {
 
      ##force version number
     if(!is.null(forced.VersionNumber)){
@@ -321,15 +361,15 @@ read_BIN2R <- function(
       if(temp.ID > 0){
 
         if(is.null(n.records)){
-          warning(paste0("[read_BIN2R()] BIN-file appears to be corrupt. Import limited to the first ", temp.ID-1," records."))
+          warning(paste0("[read_BIN2R()] BIN-file appears to be corrupt. Import limited to the first ", temp.ID," record(s)."))
 
         }else{
-          warning(paste0("[read_BIN2R()] BIN-file appears to be corrupt. 'n.records' reset to ", temp.ID-1,"."))
+          warning(paste0("[read_BIN2R()] BIN-file appears to be corrupt. 'n.records' reset to ", temp.ID,"."))
 
         }
 
         ##set or reset n.records
-        n.records <- temp.ID-1
+        n.records <- temp.ID
         break()
 
       }else{
@@ -347,20 +387,19 @@ read_BIN2R <- function(
     }
 
     #empty byte position
-    EMPTY<-readBin(con, what="raw", 1, size=1, endian="litte")
+    EMPTY<-readBin(con, what="raw", 1, size=1, endian="little")
 
     if(temp.VERSION == 06 | temp.VERSION == 07 | temp.VERSION == 08){
 
       ##GET record LENGTH
       temp.LENGTH  <- readBin(con, what="int", 1, size=4, endian="little")
-
-      STEPPING <- readBin(con, what="raw", temp.LENGTH-6, size=1, endian="litte")
+      STEPPING <- readBin(con, what="raw", temp.LENGTH-6, size=1, endian="little")
 
     }else{
 
       ##GET record LENGTH
       temp.LENGTH  <- readBin(con, what="int", 1, size=2, endian="little")
-      STEPPING <- readBin(con, what="raw", temp.LENGTH-4, size=1, endian="litte")
+      STEPPING <- readBin(con, what="raw", temp.LENGTH-4, size=1, endian="little")
 
     }
 
@@ -615,7 +654,7 @@ read_BIN2R <- function(
   # LOOP --------------------------------------------------------------------
 
   ##start loop for import BIN data
-  while(length(temp.VERSION<-readBin(con, what="raw", 1, size=1, endian="litte"))>0) {
+  while(length(temp.VERSION<-readBin(con, what="raw", 1, size=1, endian="little"))>0) {
 
     ##force version number
     if(!is.null(forced.VersionNumber)){
@@ -650,7 +689,7 @@ read_BIN2R <- function(
 
 
     #empty byte position
-    EMPTY<-readBin(con, what="raw", 1, size=1, endian="litte")
+    EMPTY<-readBin(con, what="raw", 1, size=1, endian="little")
 
     # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     # BINX FORMAT SUPPORT -----------------------------------------------------
